@@ -13,15 +13,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
-import testscenarios
+from unittest import mock
 
+from neutron.tests.unit import testlib_api
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib import context
 from oslo_utils import importutils
-
-from neutron.tests.unit import testlib_api
+import testscenarios
 
 from neutron_dynamic_routing.api.rpc.callbacks import resources as dr_resources
 from neutron_dynamic_routing.db import bgp_db
@@ -88,19 +87,17 @@ class TestSchedulerCallback(TestBgpDrAgentSchedulerBaseTestCase):
                                   'agentnotifiers.bgp_dr_rpc_agent_api.'
                                   'BgpDrAgentNotifyApi')
         bgp_notify_p.start()
-        rpc_conn_p = mock.patch('neutron.common.rpc.create_connection')
+        rpc_conn_p = mock.patch('neutron_lib.rpc.Connection')
         rpc_conn_p.start()
-        admin_ctx_p = mock.patch('neutron_lib.context.get_admin_context')
-        admin_ctx_p = mock.patch('neutron_lib.context.get_admin_context')
-        self.admin_ctx_m = admin_ctx_p.start()
-        self.admin_ctx_m.return_value = self.ctx
         self.plugin = bgp_plugin.BgpPlugin()
         self.scheduler = bgp_dras.ChanceScheduler()
 
     def _create_test_payload(self, context='test_ctx'):
         bgp_speaker = {'id': '11111111-2222-3333-4444-555555555555'}
-        payload = {'plugin': self.plugin, 'context': context,
-                   'bgp_speaker': bgp_speaker}
+        payload = events.DBEventPayload(
+                      context,
+                      metadata={'plugin': self.plugin},
+                      states=(bgp_speaker,))
         return payload
 
     def test__register_callbacks(self):
@@ -127,8 +124,8 @@ class TestSchedulerCallback(TestBgpDrAgentSchedulerBaseTestCase):
                 dr_resources.BGP_SPEAKER,
                 events.AFTER_CREATE,
                 self.scheduler, payload)
-            sched_bgp.assert_called_once_with(self.ctx,
-                                              payload['bgp_speaker'])
+            sched_bgp.assert_called_once_with(mock.ANY,
+                                              payload.latest_state)
 
     def test_schedule_bgp_speaker_callback_with_invalid_event(self):
         payload = self._create_test_payload()
@@ -303,11 +300,8 @@ class TestRescheduleBgpSpeaker(TestBgpDrAgentSchedulerBaseTestCase,
                                   'agentnotifiers.bgp_dr_rpc_agent_api.'
                                   'BgpDrAgentNotifyApi')
         bgp_notify_p.start()
-        rpc_conn_p = mock.patch('neutron.common.rpc.create_connection')
+        rpc_conn_p = mock.patch('neutron_lib.rpc.Connection')
         rpc_conn_p.start()
-        admin_ctx_p = mock.patch('neutron_lib.context.get_admin_context')
-        self.admin_ctx_m = admin_ctx_p.start()
-        self.admin_ctx_m.return_value = self.ctx
         self.plugin = bgp_plugin.BgpPlugin()
         self.scheduler = bgp_dras.ChanceScheduler()
         self.host1 = 'host-a'
